@@ -51,22 +51,22 @@ email                : markey@web.de
 
 #include <iostream>
 
-#include <kconfigdialogmanager.h>
+#include <tdeconfigdialogmanager.h>
 #include <kcombobox.h>           //firstRunWizard()
-#include <kcmdlineargs.h>        //initCliArgs()
+#include <tdecmdlineargs.h>        //initCliArgs()
 #include <kcursor.h>             //Amarok::OverrideCursor
 #include <kedittoolbar.h>        //slotConfigToolbars()
 #include <kglobalaccel.h>        //initGlobalShortcuts()
-#include <kglobalsettings.h>     //applyColorScheme()
+#include <tdeglobalsettings.h>     //applyColorScheme()
 #include <kiconloader.h>         //amarok Icon
 #include <kkeydialog.h>          //slotConfigShortcuts()
-#include <klocale.h>
-#include <kmessagebox.h>         //applySettings(), genericEventHandler()
+#include <tdelocale.h>
+#include <tdemessagebox.h>         //applySettings(), genericEventHandler()
 #include <krun.h>                //Amarok::invokeBrowser()
 #include <kstandarddirs.h>
 #include <kurldrag.h>            //genericEventHandler()
-#include <kaboutdata.h>
-#include <kio/job.h>
+#include <tdeaboutdata.h>
+#include <tdeio/job.h>
 
 #include <tqevent.h>              //genericEventHandler()
 #include <tqeventloop.h>          //applySettings()
@@ -117,15 +117,15 @@ appleEventProcessor(const AppleEvent *ae, AppleEvent *, long /*handlerRefCon*/)
 }
 #endif
 
-LIBAMAROK_EXPORT KAboutData aboutData( "amarok",
+LIBAMAROK_EXPORT TDEAboutData aboutData( "amarok",
     I18N_NOOP( "Amarok" ), APP_VERSION,
-    I18N_NOOP( "The audio player for KDE" ), KAboutData::License_GPL,
+    I18N_NOOP( "The audio player for TDE" ), TDEAboutData::License_GPL,
     I18N_NOOP( "(C) 2002-2003, Mark Kretschmann\n(C) 2003-2007, The Amarok Development Squad\n(C) 2007-2011, The Trinity Desktop Project" ),
     I18N_NOOP( "IRC:\nirc.freenode.net - #amarok, #amarok.de, #amarok.es\n\nFeedback:\namarok@kde.org\n\n(Build Date: " __DATE__ ")" ),
              ( "http://amarok.kde.org" ) );
 
 App::App()
-        : KApplication(KApplication::openX11RGBADisplay())
+        : TDEApplication(TDEApplication::openX11RGBADisplay())
         , m_pPlayerWindow( 0 ) //will be created in applySettings()
 {
     DEBUG_BLOCK
@@ -189,7 +189,7 @@ App::App()
     fixHyperThreading();
     // tell AtomicString that this is the GUI thread
     if ( !AtomicString::isMainThread() )
-        qWarning("AtomicString was initialized from a thread other than the GUI "
+        tqWarning("AtomicString was initialized from a thread other than the GUI "
                  "thread. This could lead to memory leaks.");
 
 #ifdef TQ_WS_MAC
@@ -279,13 +279,13 @@ namespace
 void App::handleCliArgs() //static
 {
     static char cwd[PATH_MAX];
-    KCmdLineArgs* const args = KCmdLineArgs::parsedArgs();
+    TDECmdLineArgs* const args = TDECmdLineArgs::parsedArgs();
 
     if ( args->isSet( "cwd" ) )
     {
         strncpy(cwd, args->getOption( "cwd" ), sizeof(cwd) );
         cwd[sizeof(cwd)-1] = '\0';
-        KCmdLineArgs::setCwd( cwd );
+        TDECmdLineArgs::setCwd( cwd );
     }
 
     bool haveArgs = false;
@@ -389,7 +389,7 @@ void App::handleCliArgs() //static
 
 void App::initCliArgs( int argc, char *argv[] ) //static
 {
-    static KCmdLineOptions options[] =
+    static TDECmdLineOptions options[] =
         {
             { "+[URL(s)]", I18N_NOOP( "Files/URLs to open" ), 0 },
             { "r", 0, 0 },
@@ -421,14 +421,14 @@ void App::initCliArgs( int argc, char *argv[] ) //static
             { 0, 0, 0 }
         };
 
-    KCmdLineArgs::reset();
-    KCmdLineArgs::init( argc, argv, &::aboutData ); //calls KApplication::addCmdLineOptions()
-    KCmdLineArgs::addCmdLineOptions( options );   //add our own options
+    TDECmdLineArgs::reset();
+    TDECmdLineArgs::init( argc, argv, &::aboutData ); //calls TDEApplication::addCmdLineOptions()
+    TDECmdLineArgs::addCmdLineOptions( options );   //add our own options
 }
 
 
-#include <kaction.h>
-#include <kshortcutlist.h>
+#include <tdeaction.h>
+#include <tdeshortcutlist.h>
 void App::initGlobalShortcuts()
 {
     EngineController* const ec = EngineController::instance();
@@ -481,15 +481,15 @@ void App::initGlobalShortcuts()
     m_pGlobalAccel->readSettings( kapp->config() );
     m_pGlobalAccel->updateConnections();
 
-    //TODO fix kde accel system so that kactions find appropriate global shortcuts
+    //TODO fix kde accel system so that tdeactions find appropriate global shortcuts
     //     and there is only one configure shortcuts dialog
 
-    KActionCollection* const ac = Amarok::actionCollection();
-    KAccelShortcutList list( m_pGlobalAccel );
+    TDEActionCollection* const ac = Amarok::actionCollection();
+    TDEAccelShortcutList list( m_pGlobalAccel );
 
     for( uint i = 0; i < list.count(); ++i )
     {
-        KAction *action = ac->action( list.name( i ).latin1() );
+        TDEAction *action = ac->action( list.name( i ).latin1() );
 
         if( action )
         {
@@ -715,7 +715,7 @@ void App::applySettings( bool firstTime )
         EngineBase *engine = EngineController::engine();
 
         if( firstTime || AmarokConfig::soundSystem() !=
-                         PluginManager::getService( engine )->property( "X-KDE-Amarok-name" ).toString() )
+                         PluginManager::getService( engine )->property( "X-TDE-Amarok-name" ).toString() )
         {
             //will unload engine for us first if necessary
             engine = EngineController::instance()->loadEngine();
@@ -759,7 +759,7 @@ void
 App::continueInit()
 {
     DEBUG_BLOCK
-    const KCmdLineArgs* const args = KCmdLineArgs::parsedArgs();
+    const TDECmdLineArgs* const args = TDECmdLineArgs::parsedArgs();
     bool restoreSession = args->count() == 0 || args->isSet( "append" ) || args->isSet( "enqueue" )
                                 || Amarok::config()->readBoolEntry( "AppendAsDefault", false );
 
@@ -780,7 +780,7 @@ App::continueInit()
     CollectionDB::instance()->checkDatabase();
 
     m_pMediaDeviceManager = MediaDeviceManager::instance();
-    m_pGlobalAccel    = new KGlobalAccel( TQT_TQOBJECT(this) );
+    m_pGlobalAccel    = new TDEGlobalAccel( TQT_TQOBJECT(this) );
     m_pPlaylistWindow = new PlaylistWindow();
 #ifdef TQ_WS_X11
     m_pTray           = new Amarok::TrayIcon( m_pPlaylistWindow );
@@ -860,7 +860,7 @@ App::applyColorScheme()
 
     if( AmarokConfig::schemeKDE() )
     {
-        AltBase = KGlobalSettings::alternateBackgroundColor();
+        AltBase = TDEGlobalSettings::alternateBackgroundColor();
 
         playlistWindow()->unsetPalette();
         browserBar->unsetPalette();
@@ -876,13 +876,13 @@ App::applyColorScheme()
         AltBase.setRgb( 57, 64, 98 );
 
         group.setColor( TQColorGroup::Text, TQt::white );
-        group.setColor( TQColorGroup::Link, 0xCCCCCC );
+        group.setColor( TQColorGroup::Link, 0xFFCCCCCC );
         group.setColor( TQColorGroup::Base, bg );
-        group.setColor( TQColorGroup::Foreground, 0xd7d7ef );
+        group.setColor( TQColorGroup::Foreground, 0xffd7d7ef );
         group.setColor( TQColorGroup::Background, AltBase );
 
         group.setColor( TQColorGroup::Button, AltBase );
-        group.setColor( TQColorGroup::ButtonText, 0xd7d7ef );
+        group.setColor( TQColorGroup::ButtonText, 0xffd7d7ef );
 
 //         group.setColor( TQColorGroup::Light,    TQt::cyan   /*lighter than Button color*/ );
 //         group.setColor( TQColorGroup::Midlight, TQt::blue   /*between Button and Light*/ );
@@ -903,8 +903,8 @@ App::applyColorScheme()
         using namespace Amarok::ColorScheme;
         Base       = Amarok::blue;
         Text       = TQt::white;
-        Background = 0x002090;
-        Foreground = 0x80A0FF;
+        Background = 0xFF002090;
+        Foreground = 0xFF80A0FF;
 
         //all children() derive their palette from this
         playlistWindow()->setPalette( TQPalette( group, group, group ) );
@@ -949,10 +949,10 @@ App::applyColorScheme()
         playlistWindow()->unsetPalette();
     }
 
-    // set the KListView alternate colours
-    TQObjectList* const list = playlistWindow()->queryList( "KListView" );
+    // set the TDEListView alternate colours
+    TQObjectList* const list = playlistWindow()->queryList( "TDEListView" );
     for( TQObject *o = list->first(); o; o = list->next() )
-        static_cast<KListView*>(TQT_TQWIDGET(o))->setAlternateBackground( AltBase );
+        static_cast<TDEListView*>(TQT_TQWIDGET(o))->setAlternateBackground( AltBase );
     delete list; //heap allocated!
 }
 
@@ -1077,7 +1077,7 @@ void App::engineStateChanged( Engine::State state, Engine::State oldState )
             m_pPlaylistWindow->setCaption( kapp->makeStdCaption( i18n("Playlist") ) );
         else m_pPlaylistWindow->setCaption( "Amarok" );
         TrackToolTip::instance()->clear();
-        Amarok::OSD::instance()->setImage( KIconLoader().iconPath( "amarok", -KIcon::SizeHuge ) );
+        Amarok::OSD::instance()->setImage( TDEIconLoader().iconPath( "amarok", -TDEIcon::SizeHuge ) );
         break;
 
     case Engine::Playing:
@@ -1132,11 +1132,11 @@ void App::slotConfigAmarok( const TQCString& page )
 {
     DEBUG_THREAD_FUNC_INFO
 
-    AmarokConfigDialog* dialog = static_cast<AmarokConfigDialog*>( KConfigDialog::exists( "settings" ) );
+    AmarokConfigDialog* dialog = static_cast<AmarokConfigDialog*>( TDEConfigDialog::exists( "settings" ) );
 
     if( !dialog )
     {
-        //KConfigDialog didn't find an instance of this dialog, so lets create it :
+        //TDEConfigDialog didn't find an instance of this dialog, so lets create it :
         dialog = new AmarokConfigDialog( m_pPlaylistWindow, "settings", AmarokConfig::self() );
 
         connect( dialog, TQT_SIGNAL(settingsChanged()), TQT_SLOT(applySettings()) );
@@ -1186,7 +1186,7 @@ void App::firstRunWizard()
 
     FirstRunWizard wizard;
     setTopWidget( &wizard );
-    KConfigDialogManager* config = new KConfigDialogManager(&wizard, AmarokConfig::self(), "wizardconfig");
+    TDEConfigDialogManager* config = new TDEConfigDialogManager(&wizard, AmarokConfig::self(), "wizardconfig");
     config->updateWidgets();
    // connect(config, TQT_SIGNAL(settingsChanged()), TQT_SLOT(updateSettings()));
     wizard.setCaption( makeStdCaption( i18n( "First-Run Wizard" ) ) );
@@ -1230,15 +1230,15 @@ void App::setMoodbarPrefs( bool show, bool moodier, int alter, bool withMusic )
     emit moodbarPrefs( show, moodier, alter, withMusic );
 }
 
-KIO::Job *App::trashFiles( const KURL::List &files )
+TDEIO::Job *App::trashFiles( const KURL::List &files )
 {
 #if KDE_IS_VERSION( 3, 3, 91 )
-    KIO::Job *job = KIO::trash( files, true /*show progress*/ );
+    TDEIO::Job *job = TDEIO::trash( files, true /*show progress*/ );
     Amarok::StatusBar::instance()->newProgressOperation( job ).setDescription( i18n("Moving files to trash") );
-    connect( job, TQT_SIGNAL( result( KIO::Job* ) ), this, TQT_SLOT( slotTrashResult( KIO::Job* ) ) );
+    connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ), this, TQT_SLOT( slotTrashResult( TDEIO::Job* ) ) );
     return job;
 #else
-    KIO::Job* job = KIO::move( files, KGlobalSettings::trashPath() );
+    TDEIO::Job* job = TDEIO::move( files, TDEGlobalSettings::trashPath() );
     return job;
 #endif
 }
@@ -1264,7 +1264,7 @@ void App::setRating( int n )
         Playlist::instance()->setSelectedRatings( n );
 }
 
-void App::slotTrashResult( KIO::Job *job )
+void App::slotTrashResult( TDEIO::Job *job )
 {
     if( job->error() )
         job->showErrorDialog( PlaylistWindow::self() );
@@ -1285,7 +1285,7 @@ void App::quit()
         TQTimer::singleShot( 100, this, TQT_SLOT( quit() ) );
         return;
     }
-    KApplication::quit();
+    TDEApplication::quit();
 }
 
 namespace Amarok
@@ -1297,12 +1297,12 @@ namespace Amarok
         return pApp->playlistWindow();
     }
 
-    KActionCollection *actionCollection()
+    TDEActionCollection *actionCollection()
     {
         return pApp->playlistWindow()->actionCollection();
     }
 
-    KConfig *config( const TQString &group )
+    TDEConfig *config( const TQString &group )
     {
         //Slightly more useful config() that allows setting the group simultaneously
         kapp->config()->setGroup( group );
@@ -1338,7 +1338,7 @@ namespace Amarok
     TQString saveLocation( const TQString &directory )
     {
         globalDirsMutex.lock();
-        TQString result = KGlobal::dirs()->saveLocation( "data", TQString("amarok/") + directory, true );
+        TQString result = TDEGlobal::dirs()->saveLocation( "data", TQString("amarok/") + directory, true );
         globalDirsMutex.unlock();
         return result;
     }
@@ -1488,7 +1488,7 @@ namespace Amarok
     void setUseRatings( bool use ) { App::instance()->setUseRatings( use ); }
     void setMoodbarPrefs( bool show, bool moodier, int alter, bool withMusic )
     { App::instance()->setMoodbarPrefs( show, moodier, alter, withMusic ); }
-    KIO::Job *trashFiles( const KURL::List &files ) { return App::instance()->trashFiles( files ); }
+    TDEIO::Job *trashFiles( const KURL::List &files ) { return App::instance()->trashFiles( files ); }
 }
 
 #include "app.moc"
