@@ -30,7 +30,7 @@
 #include <tqthread.h>
 #include <tqvaluestack.h>
 
-namespace KIO { class Job; }
+namespace TDEIO { class Job; }
 
 class DbConnection;
 class CoverFetcher;
@@ -195,7 +195,7 @@ class PostgresqlConnection : public DbConnection
 class LIBAMAROK_EXPORT CollectionDB : public TQObject, public EngineObserver
 {
     Q_OBJECT
-    TQ_OBJECT
+    
 
     friend class SimilarArtistsInsertionJob;
 
@@ -227,6 +227,9 @@ class LIBAMAROK_EXPORT CollectionDB : public TQObject, public EngineObserver
         void tagsChanged( const TQString &oldArtist, const TQString &oldAlbum );
         void imageFetched( const TQString &remoteURL ); //for fetching remote podcast images
 
+        // Cross-thread communication
+        void startScrobblerSimilarArtistsFetch(const TQString &);
+
     public:
         CollectionDB();
         ~CollectionDB();
@@ -429,7 +432,7 @@ class LIBAMAROK_EXPORT CollectionDB : public TQObject, public EngineObserver
 
         //cover management methods
         /** Returns the image from a given URL, network-transparently.
-         * You must run KIO::NetAccess::removeTempFile( tmpFile ) when you are finished using the image;
+         * You must run TDEIO::NetAccess::removeTempFile( tmpFile ) when you are finished using the image;
          **/
         static TQImage fetchImage( const KURL& url, TQString &tmpFile );
         /** Saves images located on the user's filesystem */
@@ -523,8 +526,8 @@ class LIBAMAROK_EXPORT CollectionDB : public TQObject, public EngineObserver
         void dirDirty( const TQString& path );
         void coverFetcherResult( CoverFetcher* );
         void similarArtistsFetched( const TQString& artist, const TQStringList& suggestions );
-        void fileOperationResult( KIO::Job *job ); // moveFile depends on it
-        void podcastImageResult( KIO::Job *job ); //for fetching remote podcast images
+        void fileOperationResult( TDEIO::Job *job ); // moveFile depends on it
+        void podcastImageResult( TDEIO::Job *job ); //for fetching remote podcast images
         void aftMigratePermanentTablesUrl( const TQString& oldUrl, const TQString& newUrl, const TQString& uniqueid ); //AFT-enable stats
         void aftMigratePermanentTablesUniqueId( const TQString& url, const TQString& oldid, const TQString& newid );
 
@@ -640,7 +643,7 @@ class LIBAMAROK_EXPORT CollectionDB : public TQObject, public EngineObserver
         bool m_moveFileJobCancelled;
 
         // for handling podcast image url redirects
-        TQMap<KIO::Job *, TQString> m_podcastImageJobs;
+        TQMap<TDEIO::Job *, TQString> m_podcastImageJobs;
 
         // protect against multiple simultaneous queries/inserts
         TQMutex m_mutex;
@@ -655,7 +658,7 @@ class INotify : public ThreadManager::DependentJob
 #endif // Q_MOC_RUN
 {
     Q_OBJECT
-    TQ_OBJECT
+    
 
     public:
         INotify( CollectionDB *parent, int fd );
