@@ -51,18 +51,18 @@ email                : markey@web.de
 #include <tqtooltip.h>
 #include <tqvbox.h>
 
-#include <kapplication.h> //kapp
+#include <tdeapplication.h> //kapp
 #include <kcombobox.h>
 #include <kiconloader.h>
 #include <klineedit.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kpushbutton.h>
 #include <kstandarddirs.h>
 
 namespace Amarok {
     int databaseTypeCode( const TQString type )
     {
-        // can't use kconfigxt for the database comboxbox since we need the DBConnection id and not the index
+        // can't use tdeconfigxt for the database comboxbox since we need the DBConnection id and not the index
         int dbType = DbConnection::sqlite;
         if ( type == "MySQL")
             dbType = DbConnection::mysql;
@@ -79,8 +79,8 @@ int AmarokConfigDialog::s_currentPage = 0;
 // PUBLIC
 //////////////////////////////////////////////////////////////////////////////////////////
 
-AmarokConfigDialog::AmarokConfigDialog( TQWidget *parent, const char* name, KConfigSkeleton *config )
-        : KConfigDialog( parent, name, config )
+AmarokConfigDialog::AmarokConfigDialog( TQWidget *parent, const char* name, TDEConfigSkeleton *config )
+        : TDEConfigDialog( parent, name, config )
         , m_engineConfig( 0 )
         , m_opt4( 0 )
 {
@@ -117,18 +117,18 @@ AmarokConfigDialog::AmarokConfigDialog( TQWidget *parent, const char* name, KCon
     TQToolTip::add( aboutEngineButton, i18n("Click to get the plugin information.") );
 
     /// Populate the engine selection combo box
-    KTrader::OfferList offers = PluginManager::query( "[X-KDE-Amarok-plugintype] == 'engine'" );
-    KTrader::OfferList::ConstIterator end( offers.end() );
-    for( KTrader::OfferList::ConstIterator it = offers.begin(); it != end; ++it ) {
+    TDETrader::OfferList offers = PluginManager::query( "[X-TDE-Amarok-plugintype] == 'engine'" );
+    TDETrader::OfferList::ConstIterator end( offers.end() );
+    for( TDETrader::OfferList::ConstIterator it = offers.begin(); it != end; ++it ) {
         // Don't list the <no engine> (void engine) entry if it's not currently active,
         // cause there's no point in choosing this engine (it's a dummy, after all).
-        if( (*it)->property( "X-KDE-Amarok-name" ).toString() == "void-engine"
+        if( (*it)->property( "X-TDE-Amarok-name" ).toString() == "void-engine"
             && AmarokConfig::soundSystem() != "void-engine" ) continue;
 
         m_soundSystem->insertItem( (*it)->name() );
         // Save name properties in TQMap for lookup
-        m_pluginName[(*it)->name()] = (*it)->property( "X-KDE-Amarok-name" ).toString();
-        m_pluginAmarokName[(*it)->property( "X-KDE-Amarok-name" ).toString()] = (*it)->name();
+        m_pluginName[(*it)->name()] = (*it)->property( "X-TDE-Amarok-name" ).toString();
+        m_pluginAmarokName[(*it)->property( "X-TDE-Amarok-name" ).toString()] = (*it)->name();
     }
 
     // Collection
@@ -185,12 +185,12 @@ AmarokConfigDialog::AmarokConfigDialog( TQWidget *parent, const char* name, KCon
 
     // Show information labels (must be done after insertions)
     TQObjectList *list = queryList( TQLABEL_OBJECT_NAME_STRING, "infoPixmap" );
-    TQPixmap const info = KGlobal::iconLoader()->iconPath( "messagebox_info", -KIcon::SizeHuge );
+    TQPixmap const info = TDEGlobal::iconLoader()->iconPath( "messagebox_info", -TDEIcon::SizeHuge );
     for( TQObject *label = list->first(); label; label = list->next() )
         static_cast<TQLabel*>(TQT_TQWIDGET(label))->setPixmap( info );
     delete list;
 
-    //stop KFont Requesters getting stupidly large
+    //stop TDEFont Requesters getting stupidly large
     list = queryList( TQLABEL_OBJECT_NAME_STRING, "m_sampleLabel" );
     for( TQObject *label = list->first(); label; label = list->next() )
         static_cast<TQLabel*>(TQT_TQWIDGET(label))->setMaximumWidth( 250 );
@@ -219,13 +219,13 @@ AmarokConfigDialog::~AmarokConfigDialog()
 }
 
 
-/** Reimplemented from KConfigDialog */
+/** Reimplemented from TDEConfigDialog */
 void AmarokConfigDialog::addPage( TQWidget *page, const TQString &itemName, const TQString &pixmapName, const TQString &header, bool manage )
 {
     // Add the widget pointer to our list, for later reference
     m_pageList << page;
 
-    KConfigDialog::addPage( page, itemName, pixmapName, header, manage );
+    TDEConfigDialog::addPage( page, itemName, pixmapName, header, manage );
 }
 
 
@@ -234,7 +234,7 @@ void AmarokConfigDialog::showPageByName( const TQCString& page )
 {
     for( uint index = 0; index < m_pageList.count(); index++ ) {
         if ( m_pageList[index]->name() == page ) {
-            KConfigDialog::showPage( index );
+            TDEConfigDialog::showPage( index );
             return;
         }
     }
@@ -252,7 +252,7 @@ void AmarokConfigDialog::showPageByName( const TQCString& page )
 
 void AmarokConfigDialog::updateButtons()
 {
-    KConfigDialog::updateButtons();
+    TDEConfigDialog::updateButtons();
 }
 
 /**
@@ -283,7 +283,7 @@ void AmarokConfigDialog::updateSettings()
     }
 
     if ( m_opt2->styleComboBox->currentText() != AmarokConfig::contextBrowserStyleSheet() ) {
-        //can't use kconfigxt for the style comboxbox's since we need the string, not the index
+        //can't use tdeconfigxt for the style comboxbox's since we need the string, not the index
         AmarokConfig::setContextBrowserStyleSheet( m_opt2->styleComboBox->currentText() );
         ContextBrowser::instance()->reloadStyleSheet();
     }
