@@ -30,8 +30,8 @@ AMAROK_EXPORT_PLUGIN( XineEngine )
 #include <cmath>
 #include "debug.h"
 
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kstandarddirs.h>
 
 #include <tqapplication.h>
@@ -62,8 +62,8 @@ namespace Log
     static uint noSuitableBuffer = 0;
 }
 
-///returns the configuration we will use. there is no KInstance, so using this hacked up method.
-//static inline TQCString configPath() { return TQFile::encodeName(KStandardDirs().localkdedir() + KStandardDirs::kde_default("data") + "amarok/xine-config"); }
+///returns the configuration we will use. there is no TDEInstance, so using this hacked up method.
+//static inline TQCString configPath() { return TQFile::encodeName(TDEStandardDirs().localtdedir() + TDEStandardDirs::kde_default("data") + "amarok/xine-config"); }
 static inline TQCString configPath() { return TQFile::encodeName(locate( "data", "amarok/") + "xine-config" ); }
 static Fader *s_fader = 0;
 static OutFader *s_outfader = 0;
@@ -962,7 +962,7 @@ XineEngine::XineEventListener( void *p, const xine_event_t* xineEvent )
         TQString
         msg = "%1 %2%";
         msg = msg.arg( TQString::fromUtf8( pd->description ) )
-                 .arg( KGlobal::locale()->formatNumber( pd->percent, 0 ) );
+                 .arg( TDEGlobal::locale()->formatNumber( pd->percent, 0 ) );
 
         TQCustomEvent *e = new TQCustomEvent( 3002 );
         e->setData( new TQString( msg ) );
@@ -1286,7 +1286,7 @@ Fader::run()
         elapsedUs += stepSizeUs;
 
         // get volume (amarok main * equalizer preamp)
-        float vol = Engine::Base::makeVolumeLogarithmic( m_engine->m_volume ) * m_engine->m_preamp;
+        float vol = XineEngine::makeVolumeLogarithmic( m_engine->m_volume ) * m_engine->m_preamp;
 
         // compute the mix factor as the percentage of time spent since fade begun
         float mix = (elapsedUs / 1000.0) / (float)m_fadeLength;
