@@ -19,9 +19,9 @@
 #include <tqvbox.h>           //baseclass
 #include <tqdatetime.h>
 
-#include <klistview.h>       //baseclass
+#include <tdelistview.h>       //baseclass
 #include <kurl.h>            //stack allocated
-#include <kio/global.h>      //filesize_t
+#include <tdeio/global.h>      //filesize_t
 #include "scrobbler.h"       //SubmitItem
 #include "metabundle.h"
 
@@ -32,7 +32,7 @@ class MediaView;
 class SpaceLabel;
 class TransferDialog;
 
-class KAction;
+class TDEAction;
 class KComboBox;
 class KDialogBase;
 class KProgress;
@@ -43,7 +43,7 @@ class TQDragObject;
 class TQLabel;
 class TQPalette;
 
-class LIBAMAROK_EXPORT MediaItem : public KListViewItem
+class LIBAMAROK_EXPORT MediaItem : public TDEListViewItem
 {
     public:
         MediaItem( TQListView* parent );
@@ -122,16 +122,16 @@ class LIBAMAROK_EXPORT MediaItem : public KListViewItem
         mutable MetaBundle *m_bundle;
 };
 
-class MediaQueue : public KListView, public DropProxyTarget
+class MediaQueue : public TDEListView, public DropProxyTarget
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
     public:
         MediaQueue(MediaBrowser *parent);
         MediaItem *findPath( TQString path );
 
-        KIO::filesize_t totalSize() const; // total size of items to transfer in KB
+        TDEIO::filesize_t totalSize() const; // total size of items to transfer in KB
         void computeSize() const; // compute total size of items to transfer in KB
         void addItemToSize( const MediaItem *item ) const;
         void subtractItemFromSize( const MediaItem *item, bool unconditonally=false ) const;
@@ -150,7 +150,7 @@ class MediaQueue : public KListView, public DropProxyTarget
         void URLsAdded(); // call after finishing adding single urls
 
         void dropProxyEvent( TQDropEvent *e );
-        // Reimplemented from KListView
+        // Reimplemented from TDEListView
         bool acceptDrag( TQDropEvent *e ) const;
         TQDragObject *dragObject();
 
@@ -165,14 +165,14 @@ class MediaQueue : public KListView, public DropProxyTarget
     private:
         void keyPressEvent( TQKeyEvent *e );
         MediaBrowser *m_parent;
-        mutable KIO::filesize_t m_totalSize;
+        mutable TDEIO::filesize_t m_totalSize;
 };
 
 
 class MediaBrowser : public TQVBox
 {
     Q_OBJECT
-  TQ_OBJECT
+  
     friend class DeviceConfigureDialog;
     friend class MediaDevice;
     friend class MediaView;
@@ -197,7 +197,7 @@ class MediaBrowser : public TQVBox
 
         TQString getInternalPluginName ( const TQString string ) { return m_pluginName[string]; }
         TQString getDisplayPluginName ( const TQString string ) { return m_pluginAmarokName[string]; }
-        const KTrader::OfferList &getPlugins() { return m_plugins; }
+        const TDETrader::OfferList &getPlugins() { return m_plugins; }
         void transcodingFinished( const TQString &src, const TQString &dst );
         bool isTranscoding() const { return m_waitForTranscode; }
         void updateStats();
@@ -208,7 +208,7 @@ class MediaBrowser : public TQVBox
         bool isQuitting() const { return m_quitting; }
 
         KURL getProxyUrl( const KURL& daapUrl ) const;
-        KToolBar* getToolBar() const { return m_toolbar; }
+        TDEToolBar* getToolBar() const { return m_toolbar; }
 
     signals:
         void availabilityChanged( bool isAvailable );
@@ -272,15 +272,15 @@ class MediaBrowser : public TQVBox
         typedef TQMap<TQString, MediaItem*> ItemMap;
         mutable TQMutex   m_itemMapMutex;
         ItemMap          m_itemMap;
-        KTrader::OfferList m_plugins;
+        TDETrader::OfferList m_plugins;
         bool             m_haveDevices;
         bool             m_quitting;
 };
 
-class MediaView : public KListView
+class MediaView : public TDEListView
 {
     Q_OBJECT
-  TQ_OBJECT
+  
     friend class MediaBrowser;
     friend class MediaDevice;
 
@@ -309,7 +309,7 @@ class MediaView : public KListView
 
     private:
         void keyPressEvent( TQKeyEvent *e );
-        // Reimplemented from KListView
+        // Reimplemented from TDEListView
         void contentsDropEvent( TQDropEvent *e );
         void viewportPaintEvent( TQPaintEvent* );
         bool acceptDrag( TQDropEvent *e ) const;
@@ -328,7 +328,7 @@ class MediaView : public KListView
 class LIBAMAROK_EXPORT MediaDevice : public TQObject, public Amarok::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
     friend class DeviceConfigureDialog;
     friend class TransferDialog;
     friend class MediaBrowser;
@@ -351,9 +351,9 @@ class LIBAMAROK_EXPORT MediaDevice : public TQObject, public Amarok::Plugin
         MediaView *view();
 
         /**
-         * @retrun a KAction that will be plugged into the media device browser toolbar
+         * @retrun a TDEAction that will be plugged into the media device browser toolbar
          */
-        virtual KAction *customAction() { return 0; }
+        virtual TDEAction *customAction() { return 0; }
 
         virtual void rmbPressed( TQListViewItem *item, const TQPoint &point, int ) { (void)item; (void) point; }
 
@@ -525,7 +525,7 @@ class LIBAMAROK_EXPORT MediaDevice : public TQObject, public Amarok::Plugin
         void scheduleDisconnect() { m_scheduledDisconnect = true; }
 
     protected slots:
-        void fileTransferred( KIO::Job *job );
+        void fileTransferred( TDEIO::Job *job );
         void fileTransferFinished();
 
     private:
@@ -547,7 +547,7 @@ class LIBAMAROK_EXPORT MediaDevice : public TQObject, public Amarok::Plugin
          * Get the capacity and freespace available on the device, in bytes
          * @return true if successful
          */
-        virtual bool getCapacity( KIO::filesize_t *total, KIO::filesize_t *available ) { Q_UNUSED(total); Q_UNUSED(available); return false; }
+        virtual bool getCapacity( TDEIO::filesize_t *total, TDEIO::filesize_t *available ) { Q_UNUSED(total); Q_UNUSED(available); return false; }
 
         /**
          * Lock device for exclusive access if possible
