@@ -30,13 +30,13 @@
 #include <tqtooltip.h>
 #include <tqvbox.h>
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kactivelabel.h>
 #include <kcombobox.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kiconloader.h>
 #include <klineedit.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kpushbutton.h>
 
 using Amarok::escapeHTML;
@@ -114,7 +114,7 @@ bool
 MediumPluginManager::detectDevices( const bool redetect, const bool nographics )
 {
     bool foundNew = false;
-    KConfig *config = Amarok::config( "MediaBrowser" );
+    TDEConfig *config = Amarok::config( "MediaBrowser" );
     if( redetect )
         DeviceManager::instance()->reconcileMediumMap();
     MediumMap mmap = MediaDeviceManager::instance()->getMediumMap();
@@ -210,7 +210,7 @@ MediumPluginManager::finished()
         (*it)->configButton()->setEnabled( (*it)->pluginCombo()->currentText() != i18n( "Do not handle" ) );
     }
 
-    KConfig *config = Amarok::config( "MediaBrowser" );
+    TDEConfig *config = Amarok::config( "MediaBrowser" );
     for( DeletedMap::Iterator dit = m_deletedMap.begin();
             dit != m_deletedMap.end();
             ++dit )
@@ -270,7 +270,7 @@ ManualDeviceAdder::ManualDeviceAdder( MediumPluginManager* mpm )
     new TQLabel( i18n( "Select the plugin to use with this device:"), vbox1 );
     m_mdaCombo = new KComboBox( false, vbox1, "m_mdacombo" );
     m_mdaCombo->insertItem( i18n( "Do not handle" ) );
-    for( KTrader::OfferList::ConstIterator it = MediaBrowser::instance()->getPlugins().begin();
+    for( TDETrader::OfferList::ConstIterator it = MediaBrowser::instance()->getPlugins().begin();
             it != MediaBrowser::instance()->getPlugins().end();
             ++it )
         m_mdaCombo->insertItem( (*it)->name() );
@@ -387,7 +387,7 @@ MediaDeviceConfig::MediaDeviceConfig( Medium *medium, MediumPluginManager *mgr,
     if( !m_medium )
         return;
 
-    KConfig *config = Amarok::config( "MediaBrowser" );
+    TDEConfig *config = Amarok::config( "MediaBrowser" );
     m_oldPlugin = config->readEntry( m_medium->id() );
     if( !m_oldPlugin.isEmpty() )
         m_new = false;
@@ -427,11 +427,11 @@ MediaDeviceConfig::MediaDeviceConfig( Medium *medium, MediumPluginManager *mgr,
     m_pluginCombo = new KComboBox( false, this );
     m_pluginCombo->insertItem( i18n( "Do not handle" ) );
 
-    for( KTrader::OfferList::ConstIterator it = MediaBrowser::instance()->getPlugins().begin();
+    for( TDETrader::OfferList::ConstIterator it = MediaBrowser::instance()->getPlugins().begin();
             it != MediaBrowser::instance()->getPlugins().end();
             ++it ){
         m_pluginCombo->insertItem( (*it)->name() );
-        if ( (*it)->property( "X-KDE-Amarok-name" ).toString() == config->readEntry( medium->id() ) )
+        if ( (*it)->property( "X-TDE-Amarok-name" ).toString() == config->readEntry( medium->id() ) )
             m_pluginCombo->setCurrentItem( (*it)->name() );
     }
 
