@@ -7,7 +7,7 @@
 #include <tqobject.h>
 #include <tqstringlist.h>
 #include <kurl.h>    //inline functions
-#include <klocale.h> //inline functions
+#include <tdelocale.h> //inline functions
 #include <taglib/audioproperties.h>
 #include "expression.h"
 #include "atomicstring.h"
@@ -27,7 +27,7 @@ namespace TagLib {
 class LIBAMAROK_EXPORT MetaBundleSaver : public TQObject
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
      MetaBundleSaver( MetaBundle *bundle );
     ~MetaBundleSaver();
