@@ -38,14 +38,14 @@
 #include <tqpixmap.h>
 #include <tqrect.h>
 
-#include <kdeversion.h>
-#include <kfilemetainfo.h>
-#include <kglobal.h>
+#include <tdeversion.h>
+#include <tdefilemetainfo.h>
+#include <tdeglobal.h>
 #include <kiconeffect.h>
 #include <kimageeffect.h>
 #include <kstandarddirs.h>
 #include <kstringhandler.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 
 #include "playlistitem.h"
 
@@ -56,14 +56,14 @@ bool    PlaylistItem::s_pixmapChanged = false;
 
 
 PlaylistItem::PlaylistItem( TQListView *listview, TQListViewItem *item )
-        : KListViewItem( listview, item )
+        : TDEListViewItem( listview, item )
         , m_album( 0 )
 {
-    KListViewItem::setVisible( false );
+    TDEListViewItem::setVisible( false );
 }
 
 PlaylistItem::PlaylistItem( const MetaBundle &bundle, TQListViewItem *lvi, bool enabled )
-        : MetaBundle( bundle ), KListViewItem( lvi->listView(), lvi->itemAbove() )
+        : MetaBundle( bundle ), TDEListViewItem( lvi->listView(), lvi->itemAbove() )
         , m_album( 0 )
         , m_deleteAfterEdit( false )
         , m_isBeingRenamed( false )
@@ -255,7 +255,7 @@ void PlaylistItem::setSelected( bool selected )
     if( isVisible() )
     {
         const bool prevSelected = isSelected();
-        KListViewItem::setSelected( selected );
+        TDEListViewItem::setSelected( selected );
         if( prevSelected && !isSelected() )
         {
             listView()->m_selCount--;
@@ -280,12 +280,12 @@ void PlaylistItem::setVisible( bool visible )
     {
         listView()->m_selCount--;
         listView()->m_selLength -= length();
-        KListViewItem::setSelected( false );
+        TDEListViewItem::setSelected( false );
         listView()->countChanged();
     }
 
     const bool prevVisible = isVisible();
-    KListViewItem::setVisible( visible );
+    TDEListViewItem::setVisible( visible );
     if( prevVisible && !isVisible() )
     {
         listView()->m_visCount--;
@@ -616,7 +616,7 @@ void PlaylistItem::paintCell( TQPainter *painter, const TQColorGroup &cg, int co
                 // Left part
                 if( column == listView()->m_firstColumn ) {
                     TQImage tmpImage = currentTrackLeft.smoothScale( 1, height(), TQ_ScaleMax );
-                    KIconEffect::colorize( tmpImage, glowBase, colorize );
+                    TDEIconEffect::colorize( tmpImage, glowBase, colorize );
                     imageTransparency( tmpImage, intensity );
                     p.drawImage( 0, 0, tmpImage, 0, 0, tmpImage.width() - 1 ); //HACK
                     leftOffset = tmpImage.width() - 1; //HACK Subtracting 1, to work around the black line bug
@@ -628,7 +628,7 @@ void PlaylistItem::paintCell( TQPainter *painter, const TQColorGroup &cg, int co
                 if( column == Playlist::instance()->mapToLogicalColumn( Playlist::instance()->numVisibleColumns() - 1 ) )
                 {
                     TQImage tmpImage = currentTrackRight.smoothScale( 1, height(), TQ_ScaleMax );
-                    KIconEffect::colorize( tmpImage, glowBase, colorize );
+                    TDEIconEffect::colorize( tmpImage, glowBase, colorize );
                     imageTransparency( tmpImage, intensity );
                     p.drawImage( width - tmpImage.width(), 0, tmpImage );
                     rightOffset = tmpImage.width();
@@ -638,7 +638,7 @@ void PlaylistItem::paintCell( TQPainter *painter, const TQColorGroup &cg, int co
                 // Middle part
                 // Here we scale the one pixel wide middel image to stretch to the full column width.
                 TQImage tmpImage = currentTrackMid.copy();
-                KIconEffect::colorize( tmpImage, glowBase, colorize );
+                TDEIconEffect::colorize( tmpImage, glowBase, colorize );
                 imageTransparency( tmpImage, intensity );
                 tmpImage = tmpImage.smoothScale( width - leftOffset - rightOffset, height() );
                 p.drawImage( leftOffset, 0, tmpImage );
@@ -701,7 +701,7 @@ void PlaylistItem::paintCell( TQPainter *painter, const TQColorGroup &cg, int co
         #if KDE_IS_VERSION( 3, 3, 91 )
         if( listView()->shadeSortColumn() && !isSelected() && listView()->columnSorted() == column )
         {
-            /* from klistview.cpp
+            /* from tdelistview.cpp
                 Copyright (C) 2000 Reginald Stadlbauer <reggie@kde.org>
                 Copyright (C) 2000,2003 Charles Samuels <charles@kde.org>
                 Copyright (C) 2000 Peter Putzer */
@@ -943,7 +943,7 @@ void PlaylistItem::moodbarJobEvent( int newState )
 
 void PlaylistItem::setup()
 {
-    KListViewItem::setup();
+    TDEListViewItem::setup();
 
     // We make the current track item a bit taller than ordinary items
     if( this == listView()->currentTrack() )
@@ -954,7 +954,7 @@ void PlaylistItem::setup()
 void PlaylistItem::paintFocus( TQPainter* p, const TQColorGroup& cg, const TQRect& r )
 {
     if( this != listView()->currentTrack() )
-        KListViewItem::paintFocus( p, cg, r );
+        TDEListViewItem::paintFocus( p, cg, r );
 }
 
 const TQString &PlaylistItem::editingText()
