@@ -43,28 +43,28 @@
 #include <tqtextcodec.h>
 #include <tqtimer.h>
 
-#include <kaboutdialog.h>
-#include <kapplication.h>
-#include <kfiledialog.h>
+#include <tdeaboutdialog.h>
+#include <tdeapplication.h>
+#include <tdefiledialog.h>
 #include <kiconloader.h>
-#include <kio/netaccess.h>
-#include <klistview.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kpopupmenu.h>
+#include <tdeio/netaccess.h>
+#include <tdelistview.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdepopupmenu.h>
 #include <kprocio.h>
-#include <kprotocolmanager.h>
+#include <tdeprotocolmanager.h>
 #include <kpushbutton.h>
 #include <krun.h>
 #include <kstandarddirs.h>
 #include <ktar.h>
 #include <ktextedit.h>
-#include <kwin.h>
+#include <twin.h>
 
-#include <knewstuff/downloaddialog.h> // knewstuff script fetching
-#include <knewstuff/engine.h>         // "
-#include <knewstuff/knewstuff.h>      // "
-#include <knewstuff/provider.h>       // "
+#include <tdenewstuff/downloaddialog.h> // tdenewstuff script fetching
+#include <tdenewstuff/engine.h>         // "
+#include <tdenewstuff/knewstuff.h>      // "
+#include <tdenewstuff/provider.h>       // "
 
 
 namespace Amarok {
@@ -111,11 +111,11 @@ namespace Amarok {
 /**
  * GHNS Customised Download implementation.
  */
-class AmarokScriptNewStuff : public KNewStuff
+class AmarokScriptNewStuff : public TDENewStuff
 {
     public:
     AmarokScriptNewStuff(const TQString &type, TQWidget *parentWidget=0)
-             : KNewStuff( type, parentWidget )
+             : TDENewStuff( type, parentWidget )
     {}
 
     bool install( const TQString& fileName )
@@ -157,10 +157,10 @@ ScriptManager::ScriptManager( TQWidget *parent, const char *name )
 
 
     /// Category items
-    m_generalCategory    = new KListViewItem( m_gui->listView, i18n( "General" ) );
-    m_lyricsCategory     = new KListViewItem( m_gui->listView, i18n( "Lyrics" ) );
-    m_scoreCategory      = new KListViewItem( m_gui->listView, i18n( "Score" ) );
-    m_transcodeCategory  = new KListViewItem( m_gui->listView, i18n( "Transcoding" ) );
+    m_generalCategory    = new TDEListViewItem( m_gui->listView, i18n( "General" ) );
+    m_lyricsCategory     = new TDEListViewItem( m_gui->listView, i18n( "Lyrics" ) );
+    m_scoreCategory      = new TDEListViewItem( m_gui->listView, i18n( "Score" ) );
+    m_transcodeCategory  = new TDEListViewItem( m_gui->listView, i18n( "Transcoding" ) );
 
     m_generalCategory  ->setSelectable( false );
     m_lyricsCategory   ->setSelectable( false );
@@ -173,7 +173,7 @@ ScriptManager::ScriptManager( TQWidget *parent, const char *name )
     m_transcodeCategory->setPixmap( 0, SmallIcon( Amarok::icon( "files" ) ) );
 
     // Restore the open/closed state of the category items
-    KConfig* const config = Amarok::config( "ScriptManager" );
+    TDEConfig* const config = Amarok::config( "ScriptManager" );
     m_generalCategory  ->setOpen( config->readBoolEntry( "General category open" ) );
     m_lyricsCategory   ->setOpen( config->readBoolEntry( "Lyrics category open" ) );
     m_scoreCategory    ->setOpen( config->readBoolEntry( "Score category State" ) );
@@ -225,7 +225,7 @@ ScriptManager::~ScriptManager()
     }
 
     // Save config
-    KConfig* const config = Amarok::config( "ScriptManager" );
+    TDEConfig* const config = Amarok::config( "ScriptManager" );
     config->writeEntry( "Running Scripts", runningScripts );
 
     // Save the open/closed state of the category items
@@ -365,7 +365,7 @@ ScriptManager::findScripts() //SLOT
 
     // Handle auto-run:
 
-    KConfig* const config = Amarok::config( "ScriptManager" );
+    TDEConfig* const config = Amarok::config( "ScriptManager" );
     const TQStringList runningScripts = config->readListEntry( "Running Scripts" );
 
     {
@@ -453,7 +453,7 @@ ScriptManager::slotInstallScript( const TQString& path )
                                      "Please inform the package maintainer about this error.</p>" ) );
 
         // Delete directory recursively
-        KIO::NetAccess::del( KURL::fromPathOrURL( scriptFolder ), 0 );
+        TDEIO::NetAccess::del( KURL::fromPathOrURL( scriptFolder ), 0 );
     }
 
     return false;
@@ -488,12 +488,12 @@ ScriptManager::recurseInstall( const KArchiveDirectory* archiveDir, const TQStri
 void
 ScriptManager::slotRetrieveScript()
 {
-    // Delete KNewStuff's configuration entries. These entries reflect which scripts
+    // Delete TDENewStuff's configuration entries. These entries reflect which scripts
     // are already installed. As we cannot yet keep them in sync after uninstalling
     // scripts, we deactivate the check marks entirely.
-    Amarok::config()->deleteGroup( "KNewStuffStatus" );
+    Amarok::config()->deleteGroup( "TDENewStuffStatus" );
 
-    // we need this because KNewStuffGeneric's install function isn't clever enough
+    // we need this because TDENewStuffGeneric's install function isn't clever enough
     AmarokScriptNewStuff *kns = new AmarokScriptNewStuff( "amarok/script", this );
     KNS::Engine *engine = new KNS::Engine( kns, "amarok/script", this );
     KNS::DownloadDialog *d = new KNS::DownloadDialog( engine, this );
@@ -501,7 +501,7 @@ ScriptManager::slotRetrieveScript()
     // you have to do this by hand when providing your own Engine
     KNS::ProviderLoader *p = new KNS::ProviderLoader( this );
     TQObject::connect( p, TQT_SIGNAL( providersLoaded(Provider::List*) ), d, TQT_SLOT( slotProviders (Provider::List *) ) );
-    p->load( "amarok/script", "http://amarok.kde.org/knewstuff/amarokscripts-providers.xml" );
+    p->load( "amarok script", "https://www.trinitydesktop.org/ocs/providers.xml" );
 
     d->exec();
 }
@@ -522,7 +522,7 @@ ScriptManager::slotUninstallScript()
 
     // find if the script is installed in the global or local scripts directory
     KURL scriptsDirURL;
-    TQStringList dirs = KGlobal::dirs()->findDirs( "data", "amarok/scripts/" );
+    TQStringList dirs = TDEGlobal::dirs()->findDirs( "data", "amarok/scripts/" );
     for ( TQStringList::Iterator it = dirs.begin(); it != dirs.end(); ++it ) {
         scriptsDirURL = KURL::fromPathOrURL( *it );
         if ( scriptsDirURL.isParentOf( scriptDirURL ) )
@@ -537,7 +537,7 @@ ScriptManager::slotUninstallScript()
     }
 
     // Delete script directory recursively
-    if( !KIO::NetAccess::del( scriptDirURL, 0 ) ) {
+    if( !TDEIO::NetAccess::del( scriptDirURL, 0 ) ) {
         KMessageBox::sorry( 0, i18n( "<p>Could not uninstall this script.</p><p>The ScriptManager can only uninstall scripts which have been installed as packages.</p>" ) ); // only true when not running as root (which is reasonable)
         return;
     }
@@ -588,16 +588,16 @@ ScriptManager::slotRunScript( bool silent )
     if( m_scripts[name].process ) return false;
 
     Amarok::ProcIO* script = new Amarok::ProcIO();
-    script->setComm( static_cast<KProcess::Communication>( KProcess::All ) );
+    script->setComm( static_cast<TDEProcess::Communication>( TDEProcess::All ) );
     const KURL url = m_scripts[name].url;
     *script << url.path();
     script->setWorkingDirectory( Amarok::saveLocation( "scripts-data/" ) );
 
-    connect( script, TQT_SIGNAL( receivedStderr( KProcess*, char*, int ) ), TQT_SLOT( slotReceivedStderr( KProcess*, char*, int ) ) );
-    connect( script, TQT_SIGNAL( receivedStdout( KProcess*, char*, int ) ), TQT_SLOT( slotReceivedStdout( KProcess*, char*, int ) ) );
-    connect( script, TQT_SIGNAL( processExited( KProcess* ) ), TQT_SLOT( scriptFinished( KProcess* ) ) );
+    connect( script, TQT_SIGNAL( receivedStderr( TDEProcess*, char*, int ) ), TQT_SLOT( slotReceivedStderr( TDEProcess*, char*, int ) ) );
+    connect( script, TQT_SIGNAL( receivedStdout( TDEProcess*, char*, int ) ), TQT_SLOT( slotReceivedStdout( TDEProcess*, char*, int ) ) );
+    connect( script, TQT_SIGNAL( processExited( TDEProcess* ) ), TQT_SLOT( scriptFinished( TDEProcess* ) ) );
 
-    if( script->start( KProcess::NotifyOnExit ) )
+    if( script->start( TDEProcess::NotifyOnExit ) )
     {
         if( m_scripts[name].type == "score" && !scoreScriptRunning().isNull() )
         {
@@ -670,7 +670,7 @@ ScriptManager::slotAboutScript()
         return;
     }
 
-    KAboutDialog* about = new KAboutDialog( KAboutDialog::AbtTabbed|KAboutDialog::AbtProduct,
+    TDEAboutDialog* about = new TDEAboutDialog( TDEAboutDialog::AbtTabbed|TDEAboutDialog::AbtProduct,
                                             TQString(),
                                             KDialogBase::Ok, KDialogBase::Ok, this );
     kapp->setTopWidget( about );
@@ -706,7 +706,7 @@ ScriptManager::slotShowContextMenu( TQListViewItem* item, const TQPoint& pos )
         if( it.data().li == item ) break;
 
     enum { SHOW_LOG, EDIT };
-    KPopupMenu menu;
+    TDEPopupMenu menu;
     menu.insertTitle( i18n( "Debugging" ) );
     menu.insertItem( SmallIconSet( Amarok::icon( "clock" ) ), i18n( "Show Output &Log" ), SHOW_LOG );
     menu.insertItem( SmallIconSet( Amarok::icon( "edit" ) ), i18n( "&Edit" ), EDIT );
@@ -716,7 +716,7 @@ ScriptManager::slotShowContextMenu( TQListViewItem* item, const TQPoint& pos )
     switch( id )
     {
         case EDIT:
-            KRun::runCommand( "kwrite " + KProcess::quote(it.data().url.path()) );
+            KRun::runCommand( "kwrite " + TDEProcess::quote(it.data().url.path()) );
             break;
 
         case SHOW_LOG:
@@ -744,14 +744,14 @@ ScriptManager::slotShowContextMenu( TQListViewItem* item, const TQPoint& pos )
 
 /* This is just a workaround, some scripts crash for some people if stdout is not handled. */
 void
-ScriptManager::slotReceivedStdout( KProcess*, char* buf, int len )
+ScriptManager::slotReceivedStdout( TDEProcess*, char* buf, int len )
 {
     debug() << TQString::fromLatin1( buf, len ) << endl;
 }
 
 
 void
-ScriptManager::slotReceivedStderr( KProcess* process, char* buf, int len )
+ScriptManager::slotReceivedStderr( TDEProcess* process, char* buf, int len )
 {
     // Look up script entry in our map
     ScriptMap::Iterator it;
@@ -769,7 +769,7 @@ ScriptManager::slotReceivedStderr( KProcess* process, char* buf, int len )
 
 
 void
-ScriptManager::scriptFinished( KProcess* process ) //SLOT
+ScriptManager::scriptFinished( TDEProcess* process ) //SLOT
 {
     // Look up script entry in our map
     ScriptMap::Iterator it;
@@ -876,25 +876,25 @@ ScriptManager::loadScript( const TQString& path )
 
         // Read and parse .spec file, if exists
         TQFileInfo info( path );
-        KListViewItem* li = 0;
+        TDEListViewItem* li = 0;
         const TQString specPath = info.dirPath() + '/' + info.baseName( true ) + ".spec";
         if( TQFile::exists( specPath ) ) {
-            KConfig spec( specPath, true, false );
+            TDEConfig spec( specPath, true, false );
             if( spec.hasKey( "name" ) )
                 name = spec.readEntry( "name" );
             if( spec.hasKey( "type" ) ) {
                 type = spec.readEntry( "type" );
                 if( type == "lyrics" )
-                    li = new KListViewItem( m_lyricsCategory, name );
+                    li = new TDEListViewItem( m_lyricsCategory, name );
                 if( type == "transcode" )
-                    li = new KListViewItem( m_transcodeCategory, name );
+                    li = new TDEListViewItem( m_transcodeCategory, name );
                 if( type == "score" )
-                    li = new KListViewItem( m_scoreCategory, name );
+                    li = new TDEListViewItem( m_scoreCategory, name );
             }
         }
 
         if( !li )
-            li = new KListViewItem( m_generalCategory, name );
+            li = new TDEListViewItem( m_generalCategory, name );
 
         li->setPixmap( 0, TQPixmap() );
 
