@@ -31,16 +31,16 @@
 #include <tqvbox.h>
 #include <tqcheckbox.h>
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kcombobox.h>
 #include <kcursor.h>
-#include <kglobal.h>
-#include <khtmlview.h>
+#include <tdeglobal.h>
+#include <tdehtmlview.h>
 #include <kiconloader.h>
 #include <ktabwidget.h>
 #include <ktextedit.h>
 #include <klineedit.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <knuminput.h>
 #include <krun.h>
 #include <kstandarddirs.h>
@@ -378,7 +378,7 @@ void TagDialog::init()
     // delete itself when closing
     setWFlags( getWFlags() | TQt::WDestructiveClose );
 
-    KConfig *config = Amarok::config( "TagDialog" );
+    TDEConfig *config = Amarok::config( "TagDialog" );
 
     kTabWidget->addTab( summaryTab, i18n( "Summary" ) );
     kTabWidget->addTab( tagsTab, i18n( "Tags" ) );
@@ -391,19 +391,19 @@ void TagDialog::init()
     kComboBox_artist->insertStringList( artists );
     kComboBox_artist->completionObject()->insertItems( artists );
     kComboBox_artist->completionObject()->setIgnoreCase( true );
-    kComboBox_artist->setCompletionMode( KGlobalSettings::CompletionPopup );
+    kComboBox_artist->setCompletionMode( TDEGlobalSettings::CompletionPopup );
 
     const TQStringList albums = CollectionDB::instance()->albumList();
     kComboBox_album->insertStringList( albums );
     kComboBox_album->completionObject()->insertItems( albums );
     kComboBox_album->completionObject()->setIgnoreCase( true );
-    kComboBox_album->setCompletionMode( KGlobalSettings::CompletionPopup );
+    kComboBox_album->setCompletionMode( TDEGlobalSettings::CompletionPopup );
 
     const TQStringList composers = CollectionDB::instance()->composerList();
     kComboBox_composer->insertStringList( composers );
     kComboBox_composer->completionObject()->insertItems( composers );
     kComboBox_composer->completionObject()->setIgnoreCase( true );
-    kComboBox_composer->setCompletionMode( KGlobalSettings::CompletionPopup );
+    kComboBox_composer->setCompletionMode( TDEGlobalSettings::CompletionPopup );
 
     kComboBox_rating->insertStringList( MetaBundle::ratingList() );
 
@@ -416,7 +416,7 @@ void TagDialog::init()
     const TQStringList labels = CollectionDB::instance()->labelList();
     //TODO: figure out a way to add auto-completion support to kTestEdit_selectedLabels
 
-    //m_labelCloud = new KHTMLPart( labels_favouriteLabelsFrame );
+    //m_labelCloud = new TDEHTMLPart( labels_favouriteLabelsFrame );
     m_labelCloud = new HTMLView( labels_favouriteLabelsFrame );
     m_labelCloud->view()->setSizePolicy( TQSizePolicy::Ignored, TQSizePolicy::Ignored, false );
     m_labelCloud->view()->setVScrollBarMode( TQScrollView::AlwaysOff );
@@ -685,9 +685,9 @@ void TagDialog::readTags()
 
     summaryText += body2cols.arg( i18n("Playcount"), TQString::number( m_bundle.playCount() ) );
     summaryText += body2cols.arg( i18n("First Played"),
-                   m_bundle.playCount() ? KGlobal::locale()->formatDate( CollectionDB::instance()->getFirstPlay( m_bundle.url().path() ).date() , true ) : i18n("Never") );
+                   m_bundle.playCount() ? TDEGlobal::locale()->formatDate( CollectionDB::instance()->getFirstPlay( m_bundle.url().path() ).date() , true ) : i18n("Never") );
     summaryText += body2cols.arg( i18n("a single item (singular)", "Last Played"),
-                   m_bundle.playCount() ? KGlobal::locale()->formatDate( CollectionDB::instance()->getLastPlay( m_bundle.url().path() ).date() , true ) : i18n("Never") );
+                   m_bundle.playCount() ? TDEGlobal::locale()->formatDate( CollectionDB::instance()->getLastPlay( m_bundle.url().path() ).date() , true ) : i18n("Never") );
 
     summaryText += "</table></td></tr></table>";
     summaryLabel->setText( summaryText );
